'use strict';

var stacktraceParser = require("stacktrace-parser");
var objectOmit = require("object.omit");

var printError = require("../print-error");
var parseStacktrace = require("./stack/parse");
var filterModules = require("./stack/filter-modules");
var filterAllModules = require("./stack/filter-all-modules");
var collapseIgnored = require("./stack/collapse-ignored");

module.exports = function parseError(error) {
    return {
        name: error.name,
        message: error.message,
        stack: parseStacktrace(error.stack),
        properties: objectOmit(error, ["name", "message", "stack"]),
        stackWithout: function stackWithout(modules) {
            var collapse = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

            var filteredStack = void 0;

            if (modules === "*") {
                filteredStack = filterAllModules(this.stack);
            } else {
                filteredStack = filterModules(this.stack, modules);
            }

            if (collapse) {
                return collapseIgnored(filteredStack);
            } else {
                return filteredStack;
            }
        }
    };
};