'use strict';

var Promise = require("bluebird");
var fs = Promise.promisifyAll(require("fs"));

var maxAttempts = 100;

module.exports = function readError(errorFilePath) {
    var attempt = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

    return Promise.try(function () {
        return fs.readFileAsync(errorFilePath);
    }).then(function (fileContents) {
        return JSON.parse(fileContents);
    }).catch(SyntaxError, function (err) {
        if (attempt < maxAttempts) {
            /* The JSON hasn't been completely written yet. We'll retry in a bit. */
            return Promise.delay(1000).then(function () {
                reportError(errorFilePath, attempt + 1);
            });
        } else {
            throw new Error("Could not parse error file " + errorFilePath + ", and reached maximum attempts");
        }
    });
};