'use strict';

var fs = require("fs");
var os = require("os");
var path = require("path");
var unhandledError = require("unhandled-error");
var jsonStringifySafe = require("json-stringify-safe");
var envName = require("env-name");
var envInfo = require("env-info");

var serializeError = require("./serialize-error");

module.exports = function createErrorReporter(errorPath) {
	var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

	var unhandledErrorHandler = unhandledError(function (error, context) {
		console.log(context);

		var stringifiedErrorData = jsonStringifySafe({
			error: serializeError(error),
			context: context,
			environmentName: envName(),
			environmentInfo: envInfo(),
			hostname: os.hostname()
		}, undefined, "\t", function () {});

		var errorFilename = Date.now() + "_" + Math.floor(Math.random() * 100000) + ".json";

		fs.writeFileSync(path.join(errorPath, errorFilename), stringifiedErrorData);

		if (options.handler != null) {
			options.handler(error, context);
		}
	}, { doNotCrash: options.doNotCrash });

	return {
		report: unhandledErrorHandler.report.bind(unhandledErrorHandler)
	};
};